@@ -249,3 +249,12 @@ class StonClient:
             total_commission += self.get_swap_commission(path[offer_token_idx + 1], path[offer_token_idx])
         total_commission += self.get_swap_commission(path[0], path[-1])
         return total_commission
+
+    def swap(self,
+             wallet_mnemonics: str,
+             bid_amount: float,
+             bid_token_address: str,
+             min_ask_amount: float,
+             ask_token_address: str) -> bool:
+        from ston.__swapper import _swap
+        return _swap(self, wallet_mnemonics, bid_amount, bid_token_address, min_ask_amount, ask_token_address)
